@@ -89,11 +89,12 @@ extern SEXP iifR(SEXP l, SEXP a, SEXP b, SEXP na, SEXP tprom, SEXP nthreads);
 extern SEXP nifR(SEXP na, SEXP rho, SEXP args);
 extern SEXP nifInternalR(SEXP na, SEXP rho, SEXP args);
 extern SEXP nswitchR(SEXP x, SEXP na, SEXP nthreads, SEXP chkenc, SEXP args);
-extern SEXP ompEnabledR();
+extern SEXP ompEnabledR(void);
 extern SEXP pallR(SEXP na, SEXP args);
 extern SEXP panyR(SEXP na, SEXP args);
 extern SEXP pcountR(SEXP x, SEXP args);
-extern SEXP pcountNAR(SEXP x, SEXP args);
+extern SEXP pcountNAR(SEXP args);
+extern SEXP pfirstR(SEXP last, SEXP args);
 extern SEXP pmeanR(SEXP na, SEXP args);
 extern SEXP pprodR(SEXP na, SEXP args);
 extern SEXP psumR(SEXP na, SEXP args);
